@@ -1,20 +1,25 @@
-from os.path import join as path_join
+import re
 import sys
 
 
-_cntrl_chars = map(chr, range(0x0, 0x1f) + [0x7f])
+_CNTRL_CHARS = map(chr, range(0x0, 0x1f) + [0x7f])
+_SERIALIZED_ARRAY_REGEX = re.compile(r'(a\:\d+\:\{[is]\:[^\}]+})')
 
 
 class PHPScalarException(Exception):
     pass
 
 
+class PHPSerializationException(Exception):
+    pass
+
+
 def _has_cntrl_chars(str):
     global cntrl_chars
 
     ret = False
     for char in str:
-        if char in _cntrl_chars:
+        if char in _CNTRL_CHARS:
             ret = True
             break
 
@@ -127,11 +132,19 @@ def generate_array(list_or_array, indent=2, last_level=0, end=';'):
     return '\n'.join(parts)
 
 def serialize(mixed_value):
-    """Based on http://phpjs.org/functions/serialize/"""
+    try:
+        from phpserialize import serialize as s
+        return s(mixed_value)
+    except ImportError:
+        pass
+
+    """Based on http://phpjs.org/functions/unserialize/"""
     ktype = vals = ''
     count = 0
 
-    if type(mixed_value) is bool:
+    if mixed_value is None:
+        return 'N;'
+    elif type(mixed_value) is bool:
         if mixed_value:
             return 'b:1;'
         else:
@@ -160,3 +173,7 @@ def serialize(mixed_value):
         serialized_set.append(serialize(key))
         serialized_set.append(serialize(value))
     return 'a:%d:{%s}' % (length, ''.join(serialized_set),)
+
+def unserialize(str):
+    from phpserialize import unserialize as u
+    return u(str)
